@@ -1,7 +1,7 @@
 package Log::Any::Adapter::Screen;
 
-our $DATE = '2015-12-31'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-03-04'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,11 +9,12 @@ use warnings;
 
 use Log::Any;
 use Log::Any::Adapter::Util qw(make_method);
-use base qw(Log::Any::Adapter::Base);
-use Term::ANSIColor;
-use Time::HiRes qw(time);
+use parent qw(Log::Any::Adapter::Base);
 
-my $Time0 = time();
+my $CODE_RESET = "\e[0m"; # PRECOMPUTED FROM: do { require Term::ANSIColor; Term::ANSIColor::color('reset') }
+my $DEFAULT_COLORS = {alert=>"\e[31m",critical=>"\e[31m",debug=>"",emergency=>"\e[31m",error=>"\e[35m",info=>"\e[32m",notice=>"\e[32m",trace=>"\e[33m",warning=>"\e[1;34m"}; # PRECOMPUTED FROM: do { require Term::ANSIColor; my $tmp = {trace=>'yellow', debug=>'', info=>'green',notice=>'green',warning=>'bold blue',error=>'magenta',critical=>'red',alert=>'red',emergency=>'red'}; for (keys %$tmp) { if ($tmp->{$_}) { $tmp->{$_} = Term::ANSIColor::color($tmp->{$_}) } }; $tmp }
+
+my $Time0;
 
 my @logging_methods = Log::Any->logging_methods;
 our %logging_levels;
@@ -27,7 +28,7 @@ sub _min_level {
     my $self = shift;
 
     return $ENV{LOG_LEVEL}
-        if $ENV{LOG_LEVEL} && $logging_levels{$ENV{LOG_LEVEL}};
+        if $ENV{LOG_LEVEL} && defined $logging_levels{$ENV{LOG_LEVEL}};
     return 'trace' if $ENV{TRACE};
     return 'debug' if $ENV{DEBUG};
     return 'info'  if $ENV{VERBOSE};
@@ -40,27 +41,33 @@ sub init {
     $self->{default_level} //= 'warning';
     $self->{stderr}    //= 1;
     $self->{use_color} //= (-t STDOUT);
-    $self->{colors}    //= {
-        trace     => 'yellow',
-        debug     => '',
-        info      => 'green',
-        notice    => 'green',
-        warning   => 'bold blue',
-        error     => 'magenta',
-        critical  => 'red',
-        alert     => 'red',
-        emergency => 'red',
-    };
+    if ($self->{colors}) {
+        require Term::ANSIColor;
+        # convert color names to escape sequence
+        my $orig = $self->{colors};
+        $self->{colors} = {
+            map {($_,($orig->{$_} ? Term::ANSIColor::color($orig->{$_}) : ''))}
+                keys %$orig
+            };
+    } else {
+        $self->{colors} = $DEFAULT_COLORS;
+    }
     $self->{min_level} //= $self->_min_level;
-    $self->{formatter} //= sub {
-        my ($self, $msg) = @_;
-        my $env = $ENV{LOG_PREFIX} // '';
-        if ($env eq 'elapsed') {
-            my $time = time();
-            $msg = sprintf("[%9.3fms] %s", ($time - $Time0)*1000, $msg);
+    if (!$self->{formatter}) {
+        if (($ENV{LOG_PREFIX} // '') eq 'elapsed') {
+            require Time::HiRes;
+            $Time0 //= Time::HiRes::time();
         }
-        $msg;
-    };
+        $self->{formatter} = sub {
+            my ($self, $msg) = @_;
+            my $env = $ENV{LOG_PREFIX} // '';
+            if ($env eq 'elapsed') {
+                my $time = Time::HiRes::time();
+                $msg = sprintf("[%9.3fms] %s", ($time - $Time0)*1000, $msg);
+            }
+            $msg;
+        };
+    }
     $self->{_fh} = $self->{stderr} ? \*STDERR : \*STDOUT;
 }
 
@@ -90,7 +97,7 @@ for my $method (Log::Any->logging_methods()) {
             }
 
             if ($self->{use_color} && $self->{colors}{$method}) {
-                $msg = Term::ANSIColor::colored($msg, $self->{colors}{$method});
+                $msg = $self->{colors}{$method} . $msg . $CODE_RESET;
             }
 
             print { $self->{_fh} } $msg;
@@ -126,7 +133,7 @@ Log::Any::Adapter::Screen - Send logs to screen, with colors and some other feat
 
 =head1 VERSION
 
-This document describes version 0.10 of Log::Any::Adapter::Screen (from Perl distribution Log-Any-Adapter-Screen), released on 2015-12-31.
+This document describes version 0.12 of Log::Any::Adapter::Screen (from Perl distribution Log-Any-Adapter-Screen), released on 2016-03-04.
 
 =head1 SYNOPSIS
 
@@ -221,18 +228,6 @@ default for C<min_level>. See documentation about C<min_level> for more details.
 LOG_PREFIX. The default formatter groks these variables. See documentation about
 C<formatter> about more details.
 
-=head1 SEE ALSO
-
-Originally inspired by L<Log::Log4perl::Appender::ScreenColoredLevel>. The old
-name for this adapter is Log::Any::Adapter::ScreenColoredLevel but at some point
-I figure using a shorter name is better for my fingers.
-
-L<Log::Any>
-
-L<Log::Log4perl::Appender::ScreenColoredLevel>
-
-L<Term::ANSIColor>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Adapter-Screen>.
@@ -249,13 +244,25 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Originally inspired by L<Log::Log4perl::Appender::ScreenColoredLevel>. The old
+name for this adapter is Log::Any::Adapter::ScreenColoredLevel but at some point
+I figure using a shorter name is better for my fingers.
+
+L<Log::Any>
+
+L<Log::Log4perl::Appender::ScreenColoredLevel>
+
+L<Term::ANSIColor>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
